Package 'Al2O3AnalysisApp'

Title: 'Shiny' Application for the Analysis of Al2O3:C Chips Measurements
Description: A 'shiny' application providing an exhanced graphical user interface to the function analyse_Al2O3C_Measurement() from the R package 'Luminescence'.
Authors: Sebastian Kreutzer [aut] (ORCID: <https://orcid.org/0000-0002-0734-2199>), Nicolas Frerebeau [aut] (ORCID: <https://orcid.org/0000-0001-5759-4944>), Archéosciences Bordeaux [cre], Université Bordeaux Montaigne [fnd] (ROR: <https://ror.org/03pbgwk21>), CNRS [fnd] (ROR: <https://ror.org/02feahw73>), LabEx Sciences archéologiques de Bordeaux [fnd]
Maintainer: Archéosciences Bordeaux <[email protected]>
License: GPL (>= 3)
Version: 0.1.2.9000
Built: 2026-06-03 06:58:38 UTC
Source: https://github.com/crp2a/Al2O3_AnalysisApp

Help Index


Run a Shiny App

Description

A wrapper for shiny::shinyAppDir().

Usage

run_app(browser = TRUE, display = "auto")

Arguments

browser

A logical scalar: should the app be run in the browser?

display

A character string specifying the mode in which to display the application (see shiny::runApp()).

Value

A shiny application object.

Author(s)

N. Frerebeau

Examples

## Not run: 
run_app()

## End(Not run)